# BibleMate AI 繁體中文版

**BibleMate AI** 是一款開創性的自主 AI 代理，旨在徹底改變您的聖經學習方式。它可以創建學習計劃、協調多種聖經工具，並採取多步驟行動來完成複雜的聖經相關任務，例如對特定聖經經文進行深入研究。

開發者：Eliran Wong

## 👀 概述

[![觀看影片](httpshttps://img.youtube.com/vi/BxpLmpCm4QU/maxresdefault.jpg)](https://youtu.be/BxpLmpCm4QU)

## ✨ 核心功能

- **自主 AI 代理：** BibleMate AI 可以獨立運作，滿足您的聖經學習請求。
- **多步驟任務執行：** 它可以將複雜的任務分解為更小、更易於管理的步驟，並按順序執行。
- **豐富的工具集：** 內建超過 40 種聖經工具，由我們全面的聖經套件 [UniqueBible App](https://github.com/eliranwong/UniqueBible) 提供支援。
- **可自訂和可擴展：** 進階用戶可以自訂現有工具或添加新工具以滿足其特定需求。
- **靈活的 AI 後端：** 透過 [AgentMake AI](httpshttps://github.com/eliranwong/agentmake) 支援各種 AI 後端。

## 文件

https://github.com/eliranwong/biblematetc/blob/main/README.md
